from os import getcwd, sep, altsep, mkdir, access, F_OK
import project
from anuga.abstract_2d_finite_volumes.util import sww2timeseries, get_gauges_from_file

# Derive scenario name
p = getcwd().split(sep)
scenario = p[-1] # Last element of absolute CWD path
scenario_name = scenario.split('_2006')[0] # Strip any text past `_2006`
test = scenario_name.split('_')
if len(test) <> 1:
    scenario_name = '%s %s' %(test[0], test[1])
    
# Create report directory
reportdir = getcwd()+sep+'report'+sep
if access(reportdir,F_OK) == 0:
    mkdir (reportdir)
    
# 
production_dirs = {'20061008_234702': 'Mw 8-7', # 2500 res, 750000 other res
                   #'20061016_065743': 'Mw 8-7 refined', #new interior res
                   '20061017_004409': 'Mw 8-7 refined', #new interior res
                   '20061017_022640': 'Mw 8-7 paleo sites', #new interior res 
                   'MOST': 'MOST'} # MOST input for Mw 8-7

#production_dirs = {'20061006_062319': 'Mw 8-5', # 2500 res, 750000 other res
#                   'MOST': 'MOST'} # MOST input for Mw 8-5

gauge_map = 'boundary_gauges.jpg'

# Create sections and graphs for each designated production directory
latex_output = []
swwfiles = {}
for label_id in production_dirs.keys():
    
    file_loc = project.outputdir + label_id + sep
    swwfile = file_loc + project.basename + '.sww'
    if label_id == 'MOST':
        swwfile = project.boundarydir + project.boundary_basename + '.sww'
    swwfiles[swwfile] = label_id

texname, elev_output = sww2timeseries(swwfiles,
                                      project.gauge_filename,
                                      production_dirs,
                                      report = True,
                                      reportname = 'latexoutput_boundary',
                                      #reportname = 'latexoutput_boundary_event2',
                                      plot_quantity = ['stage', 'speed'],
                                      generate_fig = True,
                                      surface = False,
                                      time_min = None,
                                      time_max = None,
                                      title_on = False,
                                      verbose = True)

latex_output.append(texname)

# Start report generation
# Future: generate_report(reportdir, scenario, report_title, 
# project.gauge_filename, max_maps, damage_maps, production_dirs, latex_output)
report_name = reportdir + 'boundary_report.tex'
#report_name = reportdir + 'boundary_report_event2.tex'
fid = open(report_name, 'w')

s = """
% This is based on an automatically generated file (by make_report.py).
%
% Manual parts are:
% * an abstract must be written in abstract.tex
% * an introduction must be written in introduction.tex; a basic outline and
%   some of the core inputs are already in place
% * outline of the modelling methodology provided in modelling_methodology.tex
% * the tsunami-genic event should be discussed in tsunami_scenario.tex
% * an computational_setup.tex file needs to be written for the particular scenario
% * the interpretation of the results needs to be written to interpretation.tex
% * maximum inundation maps need to be included in HAT_map.tex and LAT_map.tex etc.
% * damage modelling maps need to be included in HAT_damage and LAT_damage etc.
% * a summary must be written into summary.tex
% * metadata for the scenario data to be included in metadata.tex

\documentclass{article}

\usepackage{ae} % or {zefonts}
\usepackage[T1]{fontenc}
\usepackage[ansinew]{inputenc}
\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{graphicx}
\usepackage{color}
\usepackage[colorlinks]{hyperref}
\usepackage{lscape} %landcape pages support
\usepackage{setspace}
\usepackage{rotating}
\include{appendix}
\setstretch{1.25}
\\topmargin 0pt
\oddsidemargin 0pt
\evensidemargin 0pt
\marginparwidth 0.5pt
\\textwidth \paperwidth
\\advance\\textwidth -2in

"""
fid.write(s)

s = """
\date{\\today}
%\\author{Geoscience Australia}

\\begin{document}
\\title{Comparison between ANUGA and MOST}
\maketitle
"""
fid.write(s)

# Generate latex output for location points
s = '\\begin{table} \\begin{center} \n'
fid.write(s)
s = '\caption{Defined point locations for %s study area.}' %scenario_name
fid.write(s)
s = """
\label{table:locations}
\\begin{tabular}{|l|l|l|l|}\hline
\\bf{Point Name} & \\bf{Easting} & \\bf{Northing} & \\bf{Elevation}\\\\ \hline
"""
fid.write(s)

gauges, locations, elevation = get_gauges_from_file(project.gauge_filename)

for name, gauges, elev in zip(locations, gauges, elevation):
    east = gauges[0]
    north = gauges[1]
    s = '%s & %.2f & %.2f & %.2f \\\\ \hline \n' %(name.replace('_',' '), east, north, elev)
    fid.write(s)

s = '\\end{tabular} \n  \end{center} \n \end{table} \n \n'
fid.write(s)

s = '\\begin{figure}[hbt] \n \centerline{ \includegraphics[width=\paperwidth]{../report_figures/%s}}' %gauge_map
fid.write(s)

s  = """
\caption{Point locations used for boundary investigation.}  
\label{fig:points}
\end{figure}
"""
fid.write(s)
    
s = '\input{%s} \n \clearpage \n \n' %latex_output[0]
fid.write(s)

s="""
\end{document}
"""
fid.write(s)
