from os import getcwd, sep, altsep, mkdir, access, F_OK
import project
from anuga.abstract_2d_finite_volumes.util import sww2timeseries, get_gauges_from_file

def print_elev(elevfiles,production_dirs,figname):
    from pylab import plot, xlabel, ylabel, hold, ion, legend, savefig, close
    ion()
    hold(True)
    cstr = ['g', 'r', 'b', 'c', 'm', 'y', 'k']
    j = -1
    leg_label = []
    for elevfile in elevfiles.keys():
        x, elev = read_file(elevfile)
        leg_label.append(production_dirs[elevfiles[elevfile]])
        j += 1
        plot(x, elev, '.', c = cstr[j])
    xlabel('Easting')
    ylabel('Elevation')
    legend((leg_label),loc='upper right')
    savefig(figname)
    close('all')
    return

def read_file(filename):
    fid = open(filename)
    lines = fid.readlines()
    fid.close()
    x = []
    elev = []
    i = -1
    for line in lines[:]:
        i += 1
        fields = line.split(',')
        x.append(float(fields[3].strip(' ')))
        elev.append(float(fields[2].strip(' ')))
    return x, elev

# Derive scenario name
p = getcwd().split(sep)
scenario = p[-1] # Last element of absolute CWD path
scenario_name = scenario.split('_2006')[0] # Strip any text past `_2006`
test = scenario_name.split('_')
if len(test) <> 1:
    scenario_name = '%s %s' %(test[0], test[1])
    
# Create report directory
reportdir = getcwd()+sep+'report'+sep
if access(reportdir,F_OK) == 0:
    mkdir (reportdir)
    
# 
production_dirs = {'20061022_224422': 'ANUGA', # refined around paleo sites 
                   'MOST': 'MOST'} # MOST input for Mw 8-7

gauge_map = 'gauges_map_bom.jpg'

# Create sections and graphs for each designated production directory
latex_output = []
swwfiles = {}
for label_id in production_dirs.keys():
    
    file_loc = project.outputdir + label_id + sep
    swwfile = file_loc + project.basename + '.sww'
    if label_id == 'MOST':
        swwfile = project.boundarydir + project.boundary_basename + '.sww'
    swwfiles[swwfile] = label_id

texname, elev_output = sww2timeseries(swwfiles,
                                      project.gauge_filename,#project.gauge_filename_bom,
                                      production_dirs,
                                      report = True,
                                      reportname = 'latexoutput_boundary',
                                      plot_quantity = ['stage', 'speed'],
                                      generate_fig = True,
                                      surface = False,
                                      time_min = 50.0,
                                      time_max = None,
                                      title_on = True,
                                      verbose = True)

latex_output.append(texname)

elevfiles = {}
for label_id in production_dirs.keys():
    
    file_loc = project.outputdir + label_id + sep
    elevfile = file_loc + 'gauges_maxmins' + '.csv'
    if label_id == 'MOST':
        elevfile = project.boundarydir + 'gauges_maxmins' + '.csv'
    elevfiles[elevfile] = label_id

figname = 'compare_elev.png'
print_elev(elevfiles,production_dirs,reportdir+figname)

# Start report generation
report_name = reportdir + 'boundary_report.tex'
fid = open(report_name, 'w')

s = """
% This is based on an automatically generated file (by make_report.py).
%
% Manual parts are:
% * an abstract must be written in abstract.tex
% * an introduction must be written in introduction.tex; a basic outline and
%   some of the core inputs are already in place
% * outline of the modelling methodology provided in modelling_methodology.tex
% * the tsunami-genic event should be discussed in tsunami_scenario.tex
% * an computational_setup.tex file needs to be written for the particular scenario
% * the interpretation of the results needs to be written to interpretation.tex
% * maximum inundation maps need to be included in HAT_map.tex and LAT_map.tex etc.
% * damage modelling maps need to be included in HAT_damage and LAT_damage etc.
% * a summary must be written into summary.tex
% * metadata for the scenario data to be included in metadata.tex

\documentclass{article}

\usepackage{ae} % or {zefonts}
\usepackage[T1]{fontenc}
\usepackage[ansinew]{inputenc}
\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{graphicx}
\usepackage{color}
\usepackage[colorlinks]{hyperref}
\usepackage{lscape} %landcape pages support
\usepackage{setspace}
\usepackage{rotating}
\include{appendix}
\setstretch{1.25}
\\topmargin 0pt
\oddsidemargin 0pt
\evensidemargin 0pt
\marginparwidth 0.5pt
\\textwidth \paperwidth
\\advance\\textwidth -2in

"""
fid.write(s)

s = """
\date{\\today}
%\\author{Geoscience Australia}

\\begin{document}
\\title{Comparison between ANUGA and MOST - Hobart}
\maketitle
"""
fid.write(s)

s = '\\begin{figure}[hbt] \n \centerline{ \includegraphics[scale=0.6]{../report_figures/%s}}' %gauge_map
fid.write(s)

s  = """
\caption{Point locations used for boundary investigation.}  
\label{fig:points}
\end{figure}
"""
fid.write(s)

s = '\\begin{figure}[hbt] \n \centerline{ \includegraphics[width=\paperwidth]{%s}}' %figname
fid.write(s)

s  = """
\caption{Elevation data for ANUGA and MOST.}  
\label{fig:elevation}
\end{figure}
"""
fid.write(s)

s = '\input{%s} \n \clearpage \n \n' %latex_output[0]
fid.write(s)

s="""
\end{document}
"""
fid.write(s)
